# Digital Operational Resilience Act (DORA) Extension to the Meta Model
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/meta-model-dora-extension#overview)
  * [Activating the DORA Meta Model Extension](https://help.sap.com/docs/leanix/ea/meta-model-dora-extension#activating-the-dora-meta-model-extension)


An overview of fields, relations, and subtypes across application, IT component, business context, and provider fact sheets to support DORA compliance.
